@@ -117,6 +117,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 	private static final String TEXT_HTML = "text/html";
 
 	private static final String APPLICATION_OCTET_STREAM = "application/octet-stream";
+	
+	private static final String APPLICATION_OCTET_STREAM_UTF_8 = "application/octet-stream;charset=UTF-8";
 
 	private final static boolean ALWAYS_COLLECT_STATISTICS = true;
 
@@ -561,7 +563,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 						"No content type in response header for path: " + method.getURI().getPathQuery());
 			}
 			String contentType = responseHeader.getValue();
-			if (APPLICATION_OCTET_STREAM.equals(contentType))
+			if (APPLICATION_OCTET_STREAM.equals(contentType) || APPLICATION_OCTET_STREAM_UTF_8.equals(contentType))
 				return new OXResource(contentType, extractResponseBody(method));
 			else if (contentType != null && contentType.startsWith(IMAGE))
 				return new OXResource(contentType, extractResponseBody(method));
