@@ -105,6 +105,8 @@ public class SessionImpl implements Session, Serializable {
 
     private static final boolean MARK_CHANGED_FOLDERS_AS_NEEDS_SYNCHRONIZATION = false;
 
+    private static final long FOLDER_HIERARCHY_NEEDS_SYNCHRONIZATION = -1L;
+
     private static final DataObject[] EMPTY_DATA_OBJECT_ARRAY = new DataObject[0];
 
     private final static String FOLDER_HIERARCHY_ID = "";
@@ -168,7 +170,7 @@ public class SessionImpl implements Session, Serializable {
 
     private long _lastFolderSync = 0L;
 
-    private long _lastFolderChange = 0L;
+    private long _lastFolderChange = FOLDER_HIERARCHY_NEEDS_SYNCHRONIZATION;
 
     private FolderIdMapping _folderIdMapping = null;
 
@@ -382,7 +384,7 @@ public class SessionImpl implements Session, Serializable {
         }
     }
 
-    private FolderElementsStorage createFolderElementsStorage(Folder folder, DataObjectFilter filter, boolean storeResult, long oldTimestamp) throws USMException {
+    private FolderElementsStorage createFolderElementsStorage(Folder folder, DataObjectFilter filter, boolean storeResult, long oldTimestamp) {
         ContentType contentType = folder.getElementsContentType();
         return new FolderElementsStorage(
             this,
@@ -442,11 +444,13 @@ public class SessionImpl implements Session, Serializable {
             if (f.getElementsContentType() == null)
                 _syncedFolderContent.put(f.getID(), f.getTimestamp());
         }
+        if (_lastFolderChange == FOLDER_HIERARCHY_NEEDS_SYNCHRONIZATION)
+            _lastFolderChange = 0L;
         return result;
     }
 
     private void markFolderHierarchyDirty() {
-        _lastFolderChange = System.currentTimeMillis();
+        foldersChanged(FOLDER_HIERARCHY_NEEDS_SYNCHRONIZATION);
     }
 
     private FolderHierarchyStorage createFolderHierachyStorage(DataObjectFilter filter, boolean storeResult, long oldTimestamp) {
@@ -915,9 +919,11 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public boolean needsSynchronization(String folderID) {
-        if (Toolkit.provided(folderID))
-            return !_syncedFolderContent.containsKey(folderID);
-        return _lastFolderSync == 0L || _lastFolderSync < _lastFolderChange;
+        return Toolkit.provided(folderID) ? !_syncedFolderContent.containsKey(folderID) : isFolderHierarchySynchronized();
+    }
+
+    private boolean isFolderHierarchySynchronized() {
+        return _lastFolderSync != 0L && _lastFolderChange != FOLDER_HIERARCHY_NEEDS_SYNCHRONIZATION && _lastFolderSync >= _lastFolderChange;
     }
 
     public ObjectChanges waitForChanges(boolean watchFolderChanges, String[] contentChangeParentIDsToWatch, long timeout) throws USMException, InterruptedException {
@@ -1013,7 +1019,7 @@ public class SessionImpl implements Session, Serializable {
         return ObjectChangesImpl.create(false, changedFolders);
     }
 
-    private ObjectChanges doWaitForChanges(boolean watchFolderChanges, String[] contentChangeParentIDsToWatch, long end) throws DatabaseAccessException, USMSQLException, InterruptedException {
+    private ObjectChanges doWaitForChanges(boolean watchFolderChanges, String[] contentChangeParentIDsToWatch, long end) throws InterruptedException {
         ObjectChanges result = null;
         for (long waitTime = end - System.currentTimeMillis(); waitTime > 0; waitTime = end - System.currentTimeMillis()) {
             synchronized (_waitObject) {
@@ -1026,9 +1032,8 @@ public class SessionImpl implements Session, Serializable {
         return result;
     }
 
-    private ObjectChanges extractFolderChanges(boolean watchFolderChanges, String[] contentChangeParentIDsToWatch) throws DatabaseAccessException, USMSQLException {
-        new ArrayList<String>();
-        boolean folderStructureChanged = watchFolderChanges && _lastFolderChange >= _lastFolderSync;
+    private ObjectChanges extractFolderChanges(boolean watchFolderChanges, String[] contentChangeParentIDsToWatch) {
+        boolean folderStructureChanged = watchFolderChanges && !isFolderHierarchySynchronized();
         List<String> changedFolders = new ArrayList<String>();
         for (String folderId : contentChangeParentIDsToWatch) {
             if (!_syncedFolderContent.containsKey(folderId))
@@ -1145,6 +1150,7 @@ public class SessionImpl implements Session, Serializable {
                 try {
                     return getFolderIdMapping().getLongID(Integer.parseInt(shortFolderID.substring(1)));
                 } catch (NumberFormatException ignored) {
+                    // Common Exception containing error message will be generated at end of method
                 }
                 break;
             case 'F':
@@ -1348,7 +1354,7 @@ public class SessionImpl implements Session, Serializable {
         if (Toolkit.provided(folderID))
             _syncedFolderContent.remove(folderID);
         else
-            _lastFolderSync = 0L;
+            markFolderHierarchyDirty();
     }
 
     public DataObjectStorage getDataObjectCache() {
