@@ -111,7 +111,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
     // LATER we might want to make this constant configurable
     private final static long ACCESS_CHECK_INTERVAL = 300000L;
 
-    private final static long SESSION_CACHE_CHECK_INTERVAL = 60000L;
+    //private final static long SESSION_CACHE_CHECK_INTERVAL = 5000L;
 
     private final static long ONE_DAY_IN_MILLISECONDS = 24L * 60L * 60L * 1000L;
 
@@ -172,6 +172,8 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
     private ScheduledTimerTask _cleanupTask;
 
     private ScheduledTimerTask _sessionCacheCleanupTask;
+    
+    private ScheduledTimerTask _sessionCacheCleanupLogInfoTask;
 
     private int _syncRetryCount;
 
@@ -781,10 +783,33 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 new USMSessionCleanupTask(this),
                 USMSessionCleanupTask.INITIAL_DELAY,
                 USMSessionCleanupTask.EXECUTION_INTERVAL);
+            
+            long sessionCacheCheckInterval = ConfigurationProperties.USM_SESSION_CACHE_CHECK_INTERVAL_DEFAULT;
+            long sessionCacheCheckIntervalLogInfo = ConfigurationProperties.USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_DEFAULT;
+            
+            try {
+                sessionCacheCheckInterval = _configurationManager.getProperty(
+                                ConfigurationProperties.USM_SESSION_CACHE_CHECK_INTERVAL_PROPERTY, 
+                                ConfigurationProperties.USM_SESSION_CACHE_CHECK_INTERVAL_DEFAULT,
+                                true);
+                
+                sessionCacheCheckIntervalLogInfo = _configurationManager.getProperty(
+                                ConfigurationProperties.USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_PROPERTY, 
+                                ConfigurationProperties.USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_DEFAULT,
+                                true);
+
+            } catch (USMInvalidConfigurationException e) {
+                _journal.error(e.getStackTrace(), e);
+            }
             _sessionCacheCleanupTask = _timerService.scheduleAtFixedRate(
                 new USMSessionCacheCleanupTask(this),
-                SESSION_CACHE_CHECK_INTERVAL,
-                SESSION_CACHE_CHECK_INTERVAL);
+                sessionCacheCheckInterval,
+                sessionCacheCheckInterval);
+            
+            _sessionCacheCleanupLogInfoTask = _timerService.scheduleAtFixedRate(
+                new USMSessionCacheCleanupLogInfoTask(this),
+                sessionCacheCheckIntervalLogInfo,
+                sessionCacheCheckIntervalLogInfo);
         }
     }
 
@@ -853,6 +878,10 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         _usmCacheInformation.sessionsRemovedByJVM(jvmRemovals);
         _usmCacheInformation.syncStatesRemovedDueToInactivity(removedSyncStates);
     }
+    
+    public USMCacheInformation getUSMCacheInformation() {
+        return _usmCacheInformation;
+    }
 
     public void syncStateSavedToDatabase() {
         _usmCacheInformation.syncStateSavedToDatabase();
