@@ -100,10 +100,13 @@ public class SessionManagerService implements SessionManager {
 		ObjectIdMappingService mappingService = (ObjectIdMappingService) context
 				.locateService(ObjectIdMappingService.class.getName());
 		UUIDMappingService uuidService = (UUIDMappingService) context.locateService(UUIDMappingService.class.getName());
+		TimerService timerService = (TimerService)context.locateService(TimerService.class.getName());
 		
 		_delegate.activate(journal.getLog(SessionManager.class), ajaxAccess, contentTypeManager,
 				folderContentTypeProvider.getFolderContentType(), oxEventManager, configurationManager, dbAccess,
 				mappingService, uuidService);
+		
+		_delegate.setTimerService(timerService);
 	}
 
 	/*
@@ -112,6 +115,7 @@ public class SessionManagerService implements SessionManager {
 	 */
 	public void deactivate(ComponentContext context) {
 		_delegate.deactivate();
+		_delegate.setTimerService(null);
 	}
 
 	public void setManagementService(ManagementService managementService) {
@@ -122,10 +126,21 @@ public class SessionManagerService implements SessionManager {
 		_delegate.setManagementService(null);
 	}
 
+	/**
+	 * @param timerService
+	 * @deprecated It is now enabled via the activate method
+	 */
+	@Deprecated
 	public void setTimerService(TimerService timerService) {
 		_delegate.setTimerService(timerService);
 	}
 
+	/**
+     * 
+     * @param timerService
+     * @deprecated It is now disabled via the deactivate method
+     */
+	@Deprecated
 	public void unsetTimerService(TimerService timerService) {
 		_delegate.setTimerService(null);
 	}
